nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Cfg

Struct Cfg 

#[repr(transparent)]
pub struct Cfg(pub u32);
USART Configuration register. Basic USART configuration settings that typically are not changed during operation.

Tuple Fields

0: u32

Implementations

Source

impl Cfg

pub const fn enable(&self) -> bool

USART Enable.

pub const fn set_enable(&mut self, val: bool)

USART Enable.

pub const fn datalen(&self) -> Datalen

Selects the data size for the USART.

pub const fn set_datalen(&mut self, val: Datalen)

Selects the data size for the USART.

pub const fn paritysel(&self) -> Paritysel

Selects what type of parity is used by the USART.

pub const fn set_paritysel(&mut self, val: Paritysel)

Selects what type of parity is used by the USART.

pub const fn stoplen(&self) -> Stoplen

Number of stop bits appended to transmitted data. Only a single stop bit is required for received data.

pub const fn set_stoplen(&mut self, val: Stoplen)

Number of stop bits appended to transmitted data. Only a single stop bit is required for received data.

pub const fn mode32k(&self) -> bool

Selects standard or 32 kHz clocking mode.

pub const fn set_mode32k(&mut self, val: bool)

Selects standard or 32 kHz clocking mode.

pub const fn linmode(&self) -> bool

LIN break mode enable.

pub const fn set_linmode(&mut self, val: bool)

LIN break mode enable.

pub const fn ctsen(&self) -> bool

CTS Enable. Determines whether CTS is used for flow control. CTS can be from the input pin, or from the USART’s own RTS if loopback mode is enabled.

pub const fn set_ctsen(&mut self, val: bool)

CTS Enable. Determines whether CTS is used for flow control. CTS can be from the input pin, or from the USART’s own RTS if loopback mode is enabled.

pub const fn syncen(&self) -> Syncen

Selects synchronous or asynchronous operation.

pub const fn set_syncen(&mut self, val: Syncen)

Selects synchronous or asynchronous operation.

pub const fn clkpol(&self) -> Clkpol

Selects the clock polarity and sampling edge of received data in synchronous mode.

pub const fn set_clkpol(&mut self, val: Clkpol)

Selects the clock polarity and sampling edge of received data in synchronous mode.

pub const fn syncmst(&self) -> Syncmst

Synchronous mode Master select.

pub const fn set_syncmst(&mut self, val: Syncmst)

Synchronous mode Master select.

pub const fn loop_(&self) -> Loop

Selects data loopback mode.

pub const fn set_loop_(&mut self, val: Loop)

Selects data loopback mode.

pub const fn oeta(&self) -> bool

Output Enable Turnaround time enable for RS-485 operation.

pub const fn set_oeta(&mut self, val: bool)

Output Enable Turnaround time enable for RS-485 operation.

pub const fn autoaddr(&self) -> bool

Automatic Address matching enable.

pub const fn set_autoaddr(&mut self, val: bool)

Automatic Address matching enable.

pub const fn oesel(&self) -> Oesel

Output Enable Select.

pub const fn set_oesel(&mut self, val: Oesel)

Output Enable Select.

pub const fn oepol(&self) -> Oepol

Output Enable Polarity.

pub const fn set_oepol(&mut self, val: Oepol)

Output Enable Polarity.

pub const fn rxpol(&self) -> Rxpol

Receive data polarity.

pub const fn set_rxpol(&mut self, val: Rxpol)

Receive data polarity.

pub const fn txpol(&self) -> Txpol

Transmit data polarity.

pub const fn set_txpol(&mut self, val: Txpol)

Transmit data polarity.