#[repr(transparent)]pub struct Ctl(pub u32);Expand description
USART Control register. USART control settings that are more likely to change during operation.
Tuple Fields
0: u32Implementations
Sourceimpl Ctl
impl Ctl
Sourcepub const fn set_txbrken(&mut self, val: Txbrken)
pub const fn set_txbrken(&mut self, val: Txbrken)
Break Enable.
Sourcepub const fn set_addrdet(&mut self, val: bool)
pub const fn set_addrdet(&mut self, val: bool)
Enable address detect mode.
Sourcepub const fn cc(&self) -> Cc
pub const fn cc(&self) -> Cc
Continuous Clock generation. By default, SCLK is only output while data is being transmitted in synchronous mode.
Sourcepub const fn set_cc(&mut self, val: Cc)
pub const fn set_cc(&mut self, val: Cc)
Continuous Clock generation. By default, SCLK is only output while data is being transmitted in synchronous mode.
Sourcepub const fn set_clrcconrx(&mut self, val: Clrcconrx)
pub const fn set_clrcconrx(&mut self, val: Clrcconrx)
Clear Continuous Clock.
Sourcepub const fn set_autobaud(&mut self, val: bool)
pub const fn set_autobaud(&mut self, val: bool)
Autobaud enable.