#[repr(transparent)]pub struct Fifointenclr(pub u32);Expand description
FIFO interrupt enable clear (disable) and read register.
Tuple Fields
0: u32Implementations
Sourceimpl Fifointenclr
impl Fifointenclr
Sourcepub const fn txerr(&self) -> bool
pub const fn txerr(&self) -> bool
Writing one clears the corresponding bits in the FIFOINTENSET register.
Sourcepub const fn set_txerr(&mut self, val: bool)
pub const fn set_txerr(&mut self, val: bool)
Writing one clears the corresponding bits in the FIFOINTENSET register.
Sourcepub const fn rxerr(&self) -> bool
pub const fn rxerr(&self) -> bool
Writing one clears the corresponding bits in the FIFOINTENSET register.
Sourcepub const fn set_rxerr(&mut self, val: bool)
pub const fn set_rxerr(&mut self, val: bool)
Writing one clears the corresponding bits in the FIFOINTENSET register.
Sourcepub const fn txlvl(&self) -> bool
pub const fn txlvl(&self) -> bool
Writing one clears the corresponding bits in the FIFOINTENSET register.
Sourcepub const fn set_txlvl(&mut self, val: bool)
pub const fn set_txlvl(&mut self, val: bool)
Writing one clears the corresponding bits in the FIFOINTENSET register.