nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Fifointenset

Struct Fifointenset 

#[repr(transparent)]
pub struct Fifointenset(pub u32);
FIFO interrupt enable set (enable) and read register.

Tuple Fields

0: u32

Implementations

Source

impl Fifointenset

pub const fn txerr(&self) -> bool

Determines whether an interrupt occurs when a transmit error occurs, based on the TXERR flag in the FIFOSTAT register.

pub const fn set_txerr(&mut self, val: bool)

Determines whether an interrupt occurs when a transmit error occurs, based on the TXERR flag in the FIFOSTAT register.

pub const fn rxerr(&self) -> bool

Determines whether an interrupt occurs when a receive error occurs, based on the RXERR flag in the FIFOSTAT register.

pub const fn set_rxerr(&mut self, val: bool)

Determines whether an interrupt occurs when a receive error occurs, based on the RXERR flag in the FIFOSTAT register.

pub const fn txlvl(&self) -> bool

Determines whether an interrupt occurs when a the transmit FIFO reaches the level specified by the TXLVL field in the FIFOTRIG register.

pub const fn set_txlvl(&mut self, val: bool)

Determines whether an interrupt occurs when a the transmit FIFO reaches the level specified by the TXLVL field in the FIFOTRIG register.

pub const fn rxlvl(&self) -> bool

Determines whether an interrupt occurs when a the receive FIFO reaches the level specified by the TXLVL field in the FIFOTRIG register.

pub const fn set_rxlvl(&mut self, val: bool)

Determines whether an interrupt occurs when a the receive FIFO reaches the level specified by the TXLVL field in the FIFOTRIG register.