nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Fifostat

Struct Fifostat 

#[repr(transparent)]
pub struct Fifostat(pub u32);
FIFO status register.

Tuple Fields

0: u32

Implementations

Source

impl Fifostat

pub const fn txerr(&self) -> bool

TX FIFO error. Will be set if a transmit FIFO error occurs. This could be an overflow caused by pushing data into a full FIFO, or by an underflow if the FIFO is empty when data is needed. Cleared by writing a 1 to this bit.

pub const fn set_txerr(&mut self, val: bool)

TX FIFO error. Will be set if a transmit FIFO error occurs. This could be an overflow caused by pushing data into a full FIFO, or by an underflow if the FIFO is empty when data is needed. Cleared by writing a 1 to this bit.

pub const fn rxerr(&self) -> bool

RX FIFO error. Will be set if a receive FIFO overflow occurs, caused by software or DMA not emptying the FIFO fast enough. Cleared by writing a 1 to this bit.

pub const fn set_rxerr(&mut self, val: bool)

RX FIFO error. Will be set if a receive FIFO overflow occurs, caused by software or DMA not emptying the FIFO fast enough. Cleared by writing a 1 to this bit.

pub const fn perint(&self) -> bool

Peripheral interrupt. When 1, this indicates that the peripheral function has asserted an interrupt. The details can be found by reading the peripheral’s STAT register.

pub const fn set_perint(&mut self, val: bool)

Peripheral interrupt. When 1, this indicates that the peripheral function has asserted an interrupt. The details can be found by reading the peripheral’s STAT register.

pub const fn txempty(&self) -> bool

Transmit FIFO empty. When 1, the transmit FIFO is empty. The peripheral may still be processing the last piece of data.

pub const fn set_txempty(&mut self, val: bool)

Transmit FIFO empty. When 1, the transmit FIFO is empty. The peripheral may still be processing the last piece of data.

pub const fn txnotfull(&self) -> bool

Transmit FIFO not full. When 1, the transmit FIFO is not full, so more data can be written. When 0, the transmit FIFO is full and another write would cause it to overflow.

pub const fn set_txnotfull(&mut self, val: bool)

Transmit FIFO not full. When 1, the transmit FIFO is not full, so more data can be written. When 0, the transmit FIFO is full and another write would cause it to overflow.

pub const fn rxnotempty(&self) -> bool

Receive FIFO not empty. When 1, the receive FIFO is not empty, so data can be read. When 0, the receive FIFO is empty.

pub const fn set_rxnotempty(&mut self, val: bool)

Receive FIFO not empty. When 1, the receive FIFO is not empty, so data can be read. When 0, the receive FIFO is empty.

pub const fn rxfull(&self) -> bool

Receive FIFO full. When 1, the receive FIFO is full. Data needs to be read out to prevent the peripheral from causing an overflow.

pub const fn set_rxfull(&mut self, val: bool)

Receive FIFO full. When 1, the receive FIFO is full. Data needs to be read out to prevent the peripheral from causing an overflow.

pub const fn txlvl(&self) -> u8

Transmit FIFO current level. A 0 means the TX FIFO is currently empty, and the TXEMPTY and TXNOTFULL flags will be 1. Other values tell how much data is actually in the TX FIFO at the point where the read occurs. If the TX FIFO is full, the TXEMPTY and TXNOTFULL flags will be 0.

pub const fn set_txlvl(&mut self, val: u8)

Transmit FIFO current level. A 0 means the TX FIFO is currently empty, and the TXEMPTY and TXNOTFULL flags will be 1. Other values tell how much data is actually in the TX FIFO at the point where the read occurs. If the TX FIFO is full, the TXEMPTY and TXNOTFULL flags will be 0.

pub const fn rxlvl(&self) -> u8

Receive FIFO current level. A 0 means the RX FIFO is currently empty, and the RXFULL and RXNOTEMPTY flags will be 0. Other values tell how much data is actually in the RX FIFO at the point where the read occurs. If the RX FIFO is full, the RXFULL and RXNOTEMPTY flags will be 1.

pub const fn set_rxlvl(&mut self, val: u8)

Receive FIFO current level. A 0 means the RX FIFO is currently empty, and the RXFULL and RXNOTEMPTY flags will be 0. Other values tell how much data is actually in the RX FIFO at the point where the read occurs. If the RX FIFO is full, the RXFULL and RXNOTEMPTY flags will be 1.