nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Intenclr

Struct Intenclr 

#[repr(transparent)]
pub struct Intenclr(pub u32);
Interrupt Enable Clear register. Allows clearing any combination of bits in the INTENSET register. Writing a 1 to any implemented bit position causes the corresponding bit to be cleared.

Tuple Fields

0: u32

Implementations

Source

impl Intenclr

pub const fn txidleclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_txidleclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn deltactsclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_deltactsclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn txdisclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_txdisclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn deltarxbrkclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_deltarxbrkclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn startclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_startclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn framerrclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_framerrclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn parityerrclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_parityerrclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn rxnoiseclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_rxnoiseclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn aberrclr(&self) -> bool

Writing 1 clears the corresponding bit in the INTENSET register.

pub const fn set_aberrclr(&mut self, val: bool)

Writing 1 clears the corresponding bit in the INTENSET register.