#[repr(transparent)]pub struct Stat(pub u32);Expand description
USART Status register. The complete status value can be read here. Writing ones clears some bits in the register. Some bits can be cleared by writing a 1 to them.
Tuple Fields
0: u32Implementations
Sourceimpl Stat
impl Stat
Sourcepub const fn rxidle(&self) -> bool
pub const fn rxidle(&self) -> bool
Receiver Idle. When 0, indicates that the receiver is currently in the process of receiving data. When 1, indicates that the receiver is not currently in the process of receiving data.
Sourcepub const fn set_rxidle(&mut self, val: bool)
pub const fn set_rxidle(&mut self, val: bool)
Receiver Idle. When 0, indicates that the receiver is currently in the process of receiving data. When 1, indicates that the receiver is not currently in the process of receiving data.
Sourcepub const fn txidle(&self) -> bool
pub const fn txidle(&self) -> bool
Transmitter Idle. When 0, indicates that the transmitter is currently in the process of sending data.When 1, indicate that the transmitter is not currently in the process of sending data.
Sourcepub const fn set_txidle(&mut self, val: bool)
pub const fn set_txidle(&mut self, val: bool)
Transmitter Idle. When 0, indicates that the transmitter is currently in the process of sending data.When 1, indicate that the transmitter is not currently in the process of sending data.
Sourcepub const fn cts(&self) -> bool
pub const fn cts(&self) -> bool
This bit reflects the current state of the CTS signal, regardless of the setting of the CTSEN bit in the CFG register. This will be the value of the CTS input pin unless loopback mode is enabled.
Sourcepub const fn set_cts(&mut self, val: bool)
pub const fn set_cts(&mut self, val: bool)
This bit reflects the current state of the CTS signal, regardless of the setting of the CTSEN bit in the CFG register. This will be the value of the CTS input pin unless loopback mode is enabled.
Sourcepub const fn deltacts(&self) -> bool
pub const fn deltacts(&self) -> bool
This bit is set when a change in the state is detected for the CTS flag above. This bit is cleared by software.
Sourcepub const fn set_deltacts(&mut self, val: bool)
pub const fn set_deltacts(&mut self, val: bool)
This bit is set when a change in the state is detected for the CTS flag above. This bit is cleared by software.
Sourcepub const fn txdisstat(&self) -> bool
pub const fn txdisstat(&self) -> bool
Transmitter Disabled Status flag. When 1, this bit indicates that the USART transmitter is fully idle after being disabled via the TXDIS bit in the CFG register (TXDIS = 1).
Sourcepub const fn set_txdisstat(&mut self, val: bool)
pub const fn set_txdisstat(&mut self, val: bool)
Transmitter Disabled Status flag. When 1, this bit indicates that the USART transmitter is fully idle after being disabled via the TXDIS bit in the CFG register (TXDIS = 1).
Sourcepub const fn rxbrk(&self) -> bool
pub const fn rxbrk(&self) -> bool
Received Break. This bit reflects the current state of the receiver break detection logic. It is set when the Un_RXD pin remains low for 16 bit times. Note that FRAMERRINT will also be set when this condition occurs because the stop bit(s) for the character would be missing. RXBRK is cleared when the Un_RXD pin goes high.
Sourcepub const fn set_rxbrk(&mut self, val: bool)
pub const fn set_rxbrk(&mut self, val: bool)
Received Break. This bit reflects the current state of the receiver break detection logic. It is set when the Un_RXD pin remains low for 16 bit times. Note that FRAMERRINT will also be set when this condition occurs because the stop bit(s) for the character would be missing. RXBRK is cleared when the Un_RXD pin goes high.
Sourcepub const fn deltarxbrk(&self) -> bool
pub const fn deltarxbrk(&self) -> bool
This bit is set when a change in the state of receiver break detection occurs. Cleared by software.
Sourcepub const fn set_deltarxbrk(&mut self, val: bool)
pub const fn set_deltarxbrk(&mut self, val: bool)
This bit is set when a change in the state of receiver break detection occurs. Cleared by software.
Sourcepub const fn start(&self) -> bool
pub const fn start(&self) -> bool
This bit is set when a start is detected on the receiver input. Its purpose is primarily to allow wake-up from Deep-sleep or Power-down mode immediately when a start is detected. Cleared by software.
Sourcepub const fn set_start(&mut self, val: bool)
pub const fn set_start(&mut self, val: bool)
This bit is set when a start is detected on the receiver input. Its purpose is primarily to allow wake-up from Deep-sleep or Power-down mode immediately when a start is detected. Cleared by software.
Sourcepub const fn framerrint(&self) -> bool
pub const fn framerrint(&self) -> bool
Framing Error interrupt flag. This flag is set when a character is received with a missing stop bit at the expected location. This could be an indication of a baud rate or configuration mismatch with the transmitting source.
Sourcepub const fn set_framerrint(&mut self, val: bool)
pub const fn set_framerrint(&mut self, val: bool)
Framing Error interrupt flag. This flag is set when a character is received with a missing stop bit at the expected location. This could be an indication of a baud rate or configuration mismatch with the transmitting source.
Sourcepub const fn parityerrint(&self) -> bool
pub const fn parityerrint(&self) -> bool
Parity Error interrupt flag. This flag is set when a parity error is detected in a received character.
Sourcepub const fn set_parityerrint(&mut self, val: bool)
pub const fn set_parityerrint(&mut self, val: bool)
Parity Error interrupt flag. This flag is set when a parity error is detected in a received character.
Sourcepub const fn rxnoiseint(&self) -> bool
pub const fn rxnoiseint(&self) -> bool
Received Noise interrupt flag. Three samples of received data are taken in order to determine the value of each received data bit, except in synchronous mode. This acts as a noise filter if one sample disagrees. This flag is set when a received data bit contains one disagreeing sample. This could indicate line noise, a baud rate or character format mismatch, or loss of synchronization during data reception.
Sourcepub const fn set_rxnoiseint(&mut self, val: bool)
pub const fn set_rxnoiseint(&mut self, val: bool)
Received Noise interrupt flag. Three samples of received data are taken in order to determine the value of each received data bit, except in synchronous mode. This acts as a noise filter if one sample disagrees. This flag is set when a received data bit contains one disagreeing sample. This could indicate line noise, a baud rate or character format mismatch, or loss of synchronization during data reception.