#[repr(transparent)]pub struct Intenclr(pub u32);Expand description
Interrupt Enable Clear register. Allows clearing any combination of bits in the INTENSET register. Writing a 1 to any implemented bit position causes the corresponding bit to be cleared.
Tuple Fields
0: u32Implementations
Sourceimpl Intenclr
impl Intenclr
Sourcepub const fn txidleclr(&self) -> bool
pub const fn txidleclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_txidleclr(&mut self, val: bool)
pub const fn set_txidleclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn deltactsclr(&self) -> bool
pub const fn deltactsclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_deltactsclr(&mut self, val: bool)
pub const fn set_deltactsclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn txdisclr(&self) -> bool
pub const fn txdisclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_txdisclr(&mut self, val: bool)
pub const fn set_txdisclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn deltarxbrkclr(&self) -> bool
pub const fn deltarxbrkclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_deltarxbrkclr(&mut self, val: bool)
pub const fn set_deltarxbrkclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn startclr(&self) -> bool
pub const fn startclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_startclr(&mut self, val: bool)
pub const fn set_startclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn framerrclr(&self) -> bool
pub const fn framerrclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_framerrclr(&mut self, val: bool)
pub const fn set_framerrclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn parityerrclr(&self) -> bool
pub const fn parityerrclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_parityerrclr(&mut self, val: bool)
pub const fn set_parityerrclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn rxnoiseclr(&self) -> bool
pub const fn rxnoiseclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_rxnoiseclr(&mut self, val: bool)
pub const fn set_rxnoiseclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn aberrclr(&self) -> bool
pub const fn aberrclr(&self) -> bool
Writing 1 clears the corresponding bit in the INTENSET register.
Sourcepub const fn set_aberrclr(&mut self, val: bool)
pub const fn set_aberrclr(&mut self, val: bool)
Writing 1 clears the corresponding bit in the INTENSET register.